@@ -1,3 +1,8 @@
+from __future__ import print_function
+
+import sys
+import json
+
 from sys import prefix
 from nb_conda_kernels.manager import CondaKernelSpecManager, RUNNER_COMMAND
 
@@ -9,8 +14,14 @@ from nb_conda_kernels.manager import CondaKernelSpecManager, RUNNER_COMMAND
 # global environment is ready to receive the other tests.
 
 
+old_print = print
+def print(x):
+    old_print('\n'.join(json.dumps(y)[1:-1] for y in x.splitlines()))
+    sys.stdout.flush()
+
+
 def test_configuration():
-    print('Conda configuration')
+    print('\nConda configuration')
     print('-------------------')
     spec_manager = CondaKernelSpecManager()
     conda_info = spec_manager._conda_info
@@ -38,6 +49,8 @@ def test_configuration():
             if key.startswith('conda-root-'):
                 checks['root_py'] = True
             if key.startswith('conda-env-'):
+                if len(key.split('-')) >= 5:
+                    checks['env_project'] = True
                 if key.endswith('-py'):
                     checks['env_py'] = True
                 if key.endswith('-r'):
@@ -56,9 +69,16 @@ def test_configuration():
     print('  - Python kernel in other environment: {}'.format(bool(checks.get('env_py'))))
     print('  - R kernel in non-test environment: {}'.format(bool(checks.get('env_r'))))
     print('  - Environment with non-ASCII name: {}'.format(bool(checks.get('env_unicode'))))
+    print('  - External project environment: {}'.format(bool(checks.get('env_project'))))
     # In some conda build scenarios, the test environment is not returned by conda
     # in the listing of conda environments.
-    assert len(checks) >= 6 - ('conda-bld' in prefix)
+    if 'conda-bld' in prefix:
+        checks.setdefault('env_current', False)
+    # It is difficult to get AppVeyor to handle Unicode environments well, but manual testing
+    # on Windows works fine. So it is likely related to the way AppVeyor captures output
+    if sys.platform.startswith('win'):
+        checks.setdefault('env_unicode', False)
+    assert len(checks) >= 7
 
 
 if __name__ == '__main__':
